package repository

import (
	"electricity_bill_calc/config"
	"electricity_bill_calc/global"
	"electricity_bill_calc/model"
	"time"

	"xorm.io/builder"
)

type _ChargeRepository struct{}

var ChargeRepo _ChargeRepository

func (_ChargeRepository) ListPagedChargeRecord(keyword, beginDate, endDate string, page int) ([]model.ChargeWithName, int64, error) {
	var cond = builder.NewCond()
	if len(keyword) != 0 {
		cond.And(builder.Like{"u.name", keyword})
	}
	if len(beginDate) != 0 {
		beginTime, err := time.Parse("2006-01-02", beginDate)
		if err != nil {
			return make([]model.ChargeWithName, 0), 0, err
		}
		cond.And(builder.Gte{"c.created_at": beginTime})
	}
	if len(endDate) != 0 {
		endTime, err := time.Parse("2006-01-02", endDate)
		if err != nil {
			return make([]model.ChargeWithName, 0), 0, err
		}
		cond.And(builder.Lte{"c.created_at": endTime})
	}
	startItem := (page - 1) * config.ServiceSettings.ItemsPageSize
	total, err := global.DBConn.
		Table("user_charge").Alias("c").
		Join("INNER", []string{"user_detail", "d"}, "c.user_id=d.id").
		Where(cond).
		Count(&model.ChargeWithName{})
	if err != nil {
		return nil, -1, err
	}
	charges := make([]model.ChargeWithName, 0)
	err = global.DBConn.
		Table("user_charge").Alias("c").
		Join("INNER", []string{"user_detail", "d"}, "c.user_id=d.id").
		Where(cond).
		Limit(config.ServiceSettings.ItemsPageSize, startItem).
		Find(&charges)
	return charges, total, err
}
